package tech.nevets.modbot.api;

import org.simpleyaml.configuration.file.YamlFile;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class Config {
    private final YamlFile CONFIG_FILE;
    private final String FILE_NAME;
    private Map<String, Object> defaults;

    private static final Logger LOGGER = LoggerFactory.getLogger(Config.class);

    public Config(String configName) {
        CONFIG_FILE = new YamlFile("./" + configName + "-config.yml");
        this.FILE_NAME = configName;
        this.defaults = new HashMap<>();
    }

    public Config(String configName, Map<String, Object> defaults) {
        CONFIG_FILE = new YamlFile("./" + configName + "-config.yml");
        this.FILE_NAME = configName;
        this.defaults = defaults;
    }

    public void addDefault(String path, Object value) {
        if (path != null && value != null) {
            defaults.put(path, value);
        }
    }

    public void addDefaults(Map<String, Object> defaults) {
        if (defaults != null) {
            this.defaults.putAll(defaults);
        }
    }

    public void loadConfig() {
        try {
            if (!CONFIG_FILE.exists()) {
                LOGGER.info("Config file not found, creating new one...");
                CONFIG_FILE.createNewFile(true);
                LOGGER.info("Config file created at: " + CONFIG_FILE.getFilePath());
            } else {
                LOGGER.info("Loading Config: " + CONFIG_FILE.getName() + "...");
                CONFIG_FILE.loadWithComments();
                LOGGER.info("Config file loaded!");
            }
        } catch (final Exception e) {
            LOGGER.error("Error while loading config:");
            e.printStackTrace();
        }

        CONFIG_FILE.addDefaults(defaults);

        try {
            CONFIG_FILE.save();
        } catch (IOException e) {
            LOGGER.error("Error saving config: ");
            e.printStackTrace();
        }
    }

    public YamlFile getConfig() {
        return CONFIG_FILE;
    }
}
